% Focused Coding Subproject: Comorbidities
% Wesley Kerr, July 2016, wesleytk@g.ucla.edu
% 
% To do Coding
% 2. Prospective data analysis & prediction
%    Automate clean matrix: Indicator vs count of comorbid, age of onsets = years
%    Permutation Tests: strange clustering of ROCs?
% 3. Kappa Analysis
% Sorta Done 4. Retrospective vs Prospective relative prevalence
%    to do: consider alternatives to ttests for count variables
% 5d. Descriptive model summary figure (predicted value for each class)
%     Errorbars: Fix SE, now for 1 exemplar
%     Done: align errorbars with correct class
%     Done: Limit to Varibales with Sig difference
%     Done: Label & Order the Classes
%     Done: Limit to ix.prev variables
%
% Done 1. Retrospective data analysis for prediction
% Done 2b. Model Summary Figure (significant and non-significant)
%     Limit to ix.prev variables
%     It'll be redundant with the flowchart but we can decide that later
% Done 5. Descriptive models to describe 5-class trends (e.g. hypothyroidism assoc
%  with PNES vs ES when control for # total comorbid)
% Done 5b. Not Controlling for Comorb
% Done 5c. All pairwise comparisons between classes
% Done 6. Table 1: Demographics & Duration of Disease
% Done 7. Raw data display
% Done 8. Create a list of MRNs with non-metastatic cancer
%
% To do non-coding
% Done 1. Predictive Model Flowchart
% 2. Descriptive Model Flowchart
% 3. Update the raw data!
%
% To do thinking/writing
% 1. Retrospective vs Prospective relative prevalence differences
% 2. Descriptive: effect of controlling for comorbidity
% 3. Descriptive vs Predictive significance
% 
% Other decisions
% 1. Ignore more specific questions asked in prospective, because that'd
% mean we have to go back in retrospective to answer anything we see (leave
% that for a future paper)

% Set up Environment and File Sources
dirs.base='/Users/wkerr/';
laptop=0;
if ~exist(dirs.base,'dir')
    dirs.base='/Users/kerr/';
    laptop=1;
    if ~exist(dirs.base,'dir')
        error 'file structure needs to be modified'
    end
end
dirs.analysis =[dirs.base 'Dropbox/ES_ComorbidMeds/'];
dirs.data     =[dirs.base 'Documents/EMU/CI/ComorbidMeds/'];
dirs.retroDx  =[dirs.data 'Retro5_ForDx.csv'];
dirs.retrodata=[dirs.data 'Retro5_ComorbidMeds.csv'];
dirs.retroarff=[dirs.analysis 'Retro5_Arff'];
dirs.retrosum =[dirs.analysis 'Retro5_ModelSummary.csv'];
dirs.sigmodel =[dirs.analysis 'SignModel.csv'];
dirs.prospDx  =[dirs.data 'Prosp_Diagnosis161122b.csv'];
dirs.prospdata=[dirs.data 'Prosp_ComorbidMeds161102.csv'];
dirs.allpts   =[dirs.data 'AllPatients161122.csv'];
dirs.prosparff=[dirs.analysis 'Prosp_Arff'];
dirs.ret2pro  =[dirs.data 'Retro2ProspIndex.csv'];
dirs.table1   =[dirs.analysis 'ComorbidMeds_Table1.csv'];
dirs.Stable1  =[dirs.analysis 'ComorbidMeds_STable1.csv'];
dirs.datatable=[dirs.analysis 'ComorbidMeds_DataTable.csv'];
dirs.rpdata   =[dirs.analysis 'ComorbidMeds_RetroProDataTable.csv'];
dirs.Descrip  =[dirs.analysis 'DescripModels.csv'];
dirs.Descrip2 =[dirs.analysis 'DescripModels_NoComorb.csv'];
dirs.retvpro  =[dirs.analysis 'RetvPro_prevalence.csv'];
dirs.retvproPNESvsES=[dirs.analysis 'RetvPro_PNESvsES.csv'];
dirs.nmetneo  =[dirs.data 'List_NonMetastaticNeoplasia.csv'];
dirs.pairwise =[dirs.analysis 'DescripPairwise.csv'];
dirs.DesOrd   =[dirs.analysis  'Descript_ClassOrd.csv'];
dirs.perffile =[dirs.analysis 'Comorb_PerfNums.csv'];

cutoff.prevalence=10; % ignore comorbidities seen in <=10 patients
doperms=0; % For permutation tests
if doperms
    n.perms=1000; % Should be 10,000 for 95% confidence
    s = RandStream('mt19937ar','Seed',sum(clock));
    RandStream.setGlobalStream(s);
end
cutoff.age        =150; % maximum allowed age
cutoff.year       =1900;% AoO above this are treated as years
ix.classord=[1 6 2 5 4 3];

Colors5=[78 195 199;
137 88 129;
243 108 54;
199 178 158;
130 71 55]/256;

%% Load Retrospective Diagnoses
fid=fopen(dirs.retroDx,'r');
d=textscan(fid,'%f %f %f %s %s %f %f %f %f %f %f %f %f %f %f %f %f %f','Delimiter',',','Headerlines',3);
fclose(fid);

ix.MRN=2;
ix.Dx =3;
ix.NumComorb  =1;
ix.Comorb     =[2:21, 23,24];
iy.notnan=find(~isnan(d{ix.MRN}));
n.retro=length(iy.notnan);
data.MRNDx=d{ix.MRN}(iy.notnan);
data.Dx   =zeros(n.retro,2);
% 1: Calc where each subdx has a unique code
% 2: NES vs ES, with mixed & inconclusive as 0
data.Dx(:,1)=d{ix.Dx}(iy.notnan);
ix.tmp=find(data.Dx(:,1)==-3);
data.Dx(ix.tmp,1)=-2;
data.Dx(:,2)=((data.Dx(:,1)>0)+(data.Dx(:,1)<0)*-1).*(data.Dx(:,1)~=-5);

%% Load Retrospective Data
fid=fopen(dirs.retrodata,'r');
h=textscan(fid,'%s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s','Delimiter',',','Headerlines',2);
fclose(fid);

fid=fopen(dirs.retrodata,'r');
d=textscan(fid,'%s %f %f %s %s %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %s %s %s %s %s %s %s %s %s','Delimiter',',','Headerlines',3);
fclose(fid);

ix.data.MRN   =3;
ix.data.Age   =6;
ix.data.Gender=7;
ix.data.Onset =8:9;
ix.data.Org   =10:30;
ix.data.Psych =31:33;
ix.data.Meds  =34:40;

% Headers
heads.Demo=cell(4,1);
heads.retro=cell(length(ix.data.Org)+length(ix.data.Psych)+length(ix.data.Meds),1);
cnt=1;
for ind=[ix.data.Age, ix.data.Gender, ix.data.Onset]
    heads.Demo{cnt}=h{ind}{1};
    cnt=cnt+1;
end
cnt=1;
for ind=[ix.data.Org, ix.data.Psych, ix.data.Meds];
    heads.retro{cnt}=h{ind}{1};
    cnt=cnt+1;
end

% Data
data.MRNdata=zeros(n.retro,1);
data.Demo=zeros(n.retro,4);
data.retro=zeros(n.retro,length(ix.data.Org)+length(ix.data.Psych)+length(ix.data.Meds));
for ind=1:length(d{1})
    iy.DxID=find(data.MRNDx==d{3}(ind));
    if isempty(iy.DxID)
        if ~isnan(d{3}(ind))
            fprintf(['Missing Dx MRN:' num2str(d{3}(ind)) '\n']);
        end
    elseif length(iy.DxID)==1
        data.MRNdata(iy.DxID)=d{3}(ind); % to check that everyone matched and no one got missed
        cnt=1;
        for jnd=[ix.data.Age, ix.data.Gender, ix.data.Onset]
            if jnd==ix.data.Gender
                data.Demo(iy.DxID,cnt)=strcmp(d{ix.data.Gender}(ind),'F');
            elseif jnd==ix.data.Age
                if d{jnd}(ind)>cutoff.age
                    error 'Invalid Age';
                end
                data.Demo(iy.DxID,cnt)=d{jnd}(ind);
            elseif intersect(jnd,ix.data.Onset)
                data.Demo(iy.DxID,cnt)=d{jnd}(ind);
            end
            cnt=cnt+1;
        end
        cnt=1;
        for jnd=[ix.data.Org, ix.data.Psych, ix.data.Meds];
            data.retro(iy.DxID,cnt)=d{jnd}(ind);
            cnt=cnt+1;
        end
    else
        error 'Doubles';
    end
end
if sum(data.MRNdata==data.MRNDx)==n.retro 
    fprintf('All Retrospective Data Loaded\n');
    
    iy.nan=find(isnan(data.retro));
    data.retro(iy.nan)=0;
    for ind=ix.Comorb
        tmp=find(data.retro(:,ind)>1); % These are supposed to be indicators
        if ~isempty(tmp)
            if length(tmp)>1
                fprintf(['Non-indicators present' heads.retro{ind} ',']);
                for jnd=1:length(tmp)
                    fprintf([num2str(tmp(jnd)) ';']);
                end
                fprintf('\n');
            else
                fprintf(['Non-indicators present' heads.retro{ind} ',' num2str(tmp) '\n']);
            end
            data.retro(tmp,ind)=1;
        end
    end
    iy.hazDx=find(data.Dx(:,2));
    iy.incDx=find(data.Dx(:,1)==0);
    iy.mixDx=find(data.Dx(:,1)==-5);
    n.Dx=length(iy.hazDx);
    n.inc=length(iy.incDx);
    n.mix=length(iy.mixDx);
    data.prevalence=sum(data.retro);
    ix.prev        =find(data.prevalence>cutoff.prevalence);
    % Output data for Weka
    create_arff(dirs.retroarff,[data.Demo(iy.hazDx,1:2),data.retro(iy.hazDx,ix.prev)],1*(data.Dx(iy.hazDx,2)>0),2); 
end

%% Predict! L1O CV
out.pred=zeros(n.Dx,5);
out.inc.pred=zeros(n.inc,5);
out.mix.pred=zeros(n.mix,5);
% 1: Prediction
% 2: Yhat
% 3: dYhat Low
% 4: dYhat High
% 5: Accurate?
heads.modeldata={heads.Demo{1:2},heads.retro{ix.prev}};
for snd=1:n.Dx
    ix.train=setdiff(1:n.Dx,snd);
    ix.test =snd;
    modeldata.Xr=[data.Demo(iy.hazDx(ix.train),1:2),data.retro(iy.hazDx(ix.train),ix.prev)];
    modeldata.Yr=1*(data.Dx(iy.hazDx(ix.train),2)>0);
    [br,devr,statsr]=glmfit(modeldata.Xr,modeldata.Yr,'binomial','link','logit');
    modeldata.Xe=[data.Demo(iy.hazDx(ix.test),1:2),data.retro(iy.hazDx(ix.test),ix.prev)];
    modeldata.Ye=1*(data.Dx(iy.hazDx(ix.test),2)>0);
    out.pred(snd,2:4)=glmval(br,modeldata.Xe,'logit',statsr);
end
[out.int.mo,out.int.dev,out.int.stats]=glmfit(ones(length(iy.hazDx),1),1*(data.Dx(iy.hazDx,2)>0),'binomial','link','logit','constant','off');
[out.mo,out.dev,out.stats]=glmfit([data.Demo(iy.hazDx,1:2),data.retro(iy.hazDx,ix.prev)],1*(data.Dx(iy.hazDx,2)>0),'binomial','link','logit');
out.devsig=1-chi2cdf(out.int.dev-out.dev,size(out.mo,1)-1);
out.pred(:,1)=round(out.pred(:,2))*2-1;
out.pred(:,5)=1*(out.pred(:,1)==data.Dx(iy.hazDx,2));
out.inc.pred(:,2)=glmval(out.mo,[data.Demo(iy.incDx,1:2),data.retro(iy.incDx,ix.prev)],'logit');
out.inc.pred(:,1)=round(out.inc.pred(:,2))*2-1;
out.inc.predsum=mean(out.inc.pred(:,1)==1);
out.inc.predCI =[binoinv(0.025,length(out.inc.pred),out.inc.predsum),binoinv(0.975,length(out.inc.pred),out.inc.predsum)]/length(out.inc.pred);
out.mix.pred(:,2)=glmval(out.mo,[data.Demo(iy.mixDx,1:2),data.retro(iy.mixDx,ix.prev)],'logit');
out.mix.pred(:,1)=round(out.mix.pred(:,2))*2-1;
out.mix.predsum=mean(out.mix.pred(:,1)==1);
out.mix.predCI =[binoinv(0.025,length(out.mix.pred),out.mix.predsum),binoinv(0.975,length(out.mix.pred),out.mix.predsum)]/length(out.mix.pred);

out.ovac=mean(out.pred(:,5));
out.chac=max(1-mean(data.Dx(iy.hazDx,2)>0),mean(data.Dx(iy.hazDx,2)>0));
if out.ovac>out.chac
    out.ovp =(1-binocdf(sum(out.pred(:,5)),length(out.pred(:,5)),out.chac))*2;
    if out.ovp>0.05
       tmpp=(1-binocdf(sum(out.pred(:,5)),length(out.pred(:,5)),out.chac))*2;
       out.reqsamp=n.sub;
       while tmpp>0.05
           out.reqsamp=out.reqsamp+1;
           tmpp=(1-binocdf(floor(out.ovac*out.reqsamp),out.reqsamp,out.chac))*2;
       end
    end
else
    out.ovp =1;
end
iy.DxES  =find(data.Dx(iy.hazDx,2)>0);
iy.DxPNES=find(data.Dx(iy.hazDx,2)<0);
out.twobytwo=zeros(2,2);
out.twobytwo(1,1)=sum(out.pred(iy.DxES  ,5)); % ES correct
out.twobytwo(2,2)=sum(out.pred(iy.DxPNES,5)); % PNES correct
out.twobytwo(1,2)=length(iy.DxES  )-out.twobytwo(1,1); % False Neg Rate
out.twobytwo(2,1)=length(iy.DxPNES)-out.twobytwo(2,2); % False Pos Rate
out.sens=out.twobytwo(1,1)/length(iy.DxES  );
out.spec=out.twobytwo(2,2)/length(iy.DxPNES);
out.PPV =out.twobytwo(1,1)/(out.twobytwo(1,1)+out.twobytwo(2,1));
out.NPV =out.twobytwo(2,2)/(out.twobytwo(2,2)+out.twobytwo(1,2));

ix.thresh=unique(out.pred(:,2));
n.thresh =length(ix.thresh);
out.ROC  =zeros(n.thresh,2);
out.AUC  =0;
data.BinDx=1*(data.Dx(iy.hazDx,2)>0);
for tnd=1:n.thresh
    iy.hi=find(out.pred(:,2)>=ix.thresh(tnd));
    iy.lo=setdiff(1:n.Dx,iy.hi);
    out.ROC(tnd,1)=length(intersect(iy.hi,iy.DxES))/length(iy.DxES); % True Positive Rate
    out.ROC(tnd,2)=1-length(intersect(iy.lo,iy.DxPNES))/length(iy.DxPNES); % False Pos Rate or 1-spec
    if tnd>1
        out.AUC=out.AUC+(1-out.ROC(tnd,2))*(out.ROC(tnd-1,1)-out.ROC(tnd,1));
    end
end

%% Write out the Retrospective-based Model
fid=fopen(dirs.retrosum,'w');
fprintf(fid,'Variable,Weight,SEWeight,p\n');
for ind=1:length(out.mo)
    if ind==1
        fprintf(fid,'Intercept,');
    else
        fprintf(fid,[heads.modeldata{ind-1} ',']);
    end
    fprintf(fid,[num2str(out.mo(ind)) ',' num2str(out.stats.se(ind)) ',' num2str(out.stats.p(ind)) '\n']);
end
fclose(fid);

%% Limiting to just significant predictors to get accurate intercept
ix.sigpred=find(out.stats.p<0.05);
if ~isempty(intersect(1,ix.sigpred)) % Remove the Intercept
    ix.sigpred=ix.sigpred(2:end);
end
if intersect(2:3,ix.sigpred) % Demographic data made it
    modeldata.Xl=[data.Demo(iy.hazDx,intersect(1:2,ix.sigpred-1)),data.retro(iy.hazDx,ix.prev(setdiff(ix.sigpred,1:3)-3))];
    if intersect(1:2,ix.sigpred-1)==2
        heads.modeldatasig={'Sex',heads.retro{ix.prev(setdiff(ix.sigpred,1:3)-3)}};
    end
else
    modeldata.Xl=data.retro(iy.hazDx,ix.prev(ix.sigpred-3));
    heads.modeldatasig=heads.retro(ix.prev(setdiff(ix.sigpred,1:3)-3));
end
[out.mol,out.devl,out.statsl]=glmfit(modeldata.Xl,1*(data.Dx(iy.hazDx,2)>0),'binomial','link','logit');
out.devsigl=1-chi2cdf(out.int.dev-out.devl,size(modeldata.Xl,2)-1);
fid=fopen(dirs.sigmodel,'w');
fprintf(fid,'Variable,Weight,SEWeight,p\n');
for ind=1:length(out.mol)
    if ind==1
        fprintf(fid,'Intercept,');
    else
        fprintf(fid,[heads.modeldatasig{ind-1} ',']);
    end
    fprintf(fid,[num2str(out.mol(ind)) ',' num2str(out.statsl.se(ind)) ',' num2str(out.statsl.p(ind)) '\n']);
end
fclose(fid);

%% Predictive Model Figures
figure;
barmod=barh(out.mo(ix.sigpred(end:-1:1)),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
set(gca,'fontsize',18);
set(gca,'ytick',1:length(ix.sigpred),'yticklabel',{heads.modeldata{ix.sigpred(end:-1:1)-1}});
set(gca,'ylim',[0.5 length(ix.sigpred)+0.5]);
set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
set(gca,'xlim',log([1/12 12]));
xlabel('PNES <- Odds Ratio -> ES');
hold on
ebs=errbar(out.mo(ix.sigpred(end:-1:1)),1:length(ix.sigpred),1.96*out.stats.se(ix.sigpred(end:-1:1)),'horiz','LineWidth',3,'Color',[0 0 0]);
hold off

figure;
barmod=barh(out.mo(end:-1:2),'BarWidth',1,'Facecolor',[0.5 0.5 0.5],'Edgecolor',[1 1 1]);
set(gca,'fontsize',18);
set(gca,'ytick',1:length(out.mo)-1,'yticklabel',{heads.modeldata{end:-1:1}});
set(gca,'ylim',[0.5 length(out.mo)-0.5]);
set(gca,'xtick',log([1/10 1/5 1/3 1/2 1 2 3 5 10]),'xticklabel',{'1/10','1/5','1/3','1/2','1','2','3','5','10'});
set(gca,'xlim',log([1/12 12]));
xlabel('PNES <- Odds Ratio -> ES');
hold on
ebs=errbar(out.mo(end:-1:2),1:length(out.mo)-1,1.96*out.stats.se(end:-1:2),'horiz','LineWidth',3,'Color',[0 0 0]);
hold off

fprintf('Retrospective Model Fit and Summarized\n');

%% Load Prospective Data
fid=fopen(dirs.prospdata,'r');
h=textscan(fid,'%s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s','Delimiter',',','Headerlines',1);
fclose(fid);
heads.prosp=cell(length(h),1);
for hnd=1:length(h)
    heads.prosp{hnd}=h{hnd}{1};
end

fid=fopen(dirs.prospdata,'r');
d=textscan(fid,'%f %s %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f','Delimiter',',','Headerlines',2);
fclose(fid);
fprintf('Follow up on qualitative entries for medications\n');
ix.prosp.MRNdata=1;
ix.prosp.date   =2;
ix.prosp.Age    =3;
ix.prosp.Gender =4;
ix.prosp.AoO    =5;
ix.prosp.Org    =6:34;
ix.prosp.Psych  =35:40;
ix.prosp.Meds   =41:47;

%% Getting the last date
data.lastdate=datetonum(d{ix.prosp.date}{1});
for ind=1:length(d{ix.prosp.date})
    if datetonum(d{ix.prosp.date}{ind})>data.lastdate
        data.lastdate=datetonum(d{ix.prosp.date}{ind});
    end
end

%% Remove Doubles
n.prosp.loaded=length(d{1});
data.prosp.MRN=zeros(n.prosp.loaded,2);
n.prosp.sub=1;
for ind=1:n.prosp.loaded
    if ind==1
        data.prosp.MRN(n.prosp.sub,1)=d{ix.prosp.MRNdata}(ind);
        data.prosp.MRN(n.prosp.sub,2)=ind;
    else
        if isempty(intersect(data.MRNdata,d{ix.prosp.MRNdata}(ind))); % MRN not in retrospective
            if isempty(intersect(data.prosp.MRN,d{ix.prosp.MRNdata}(ind))); % new MRN
                n.prosp.sub=n.prosp.sub+1;
                data.prosp.MRN(n.prosp.sub,1)=d{ix.prosp.MRNdata}(ind);
                data.prosp.MRN(n.prosp.sub,2)=ind;
            else % If there's a double, choose the earlier form
                iy.double=find(data.prosp.MRN==d{ix.prosp.MRNdata}(ind));
                olddate=datetonum(d{ix.prosp.date}{data.prosp.MRN(iy.double,2)});
                curdate=datetonum(d{ix.prosp.date}{ind});
                if curdate<olddate
                    data.prosp.MRN(iy.double,2)=ind;
                end
            end
        end
    end
end
data.prosp.MRN=data.prosp.MRN(1:n.prosp.sub,:);
data.prosp.Demo=zeros(n.prosp.sub,4);
ix.date=2;
data.pros=zeros(n.prosp.sub,length(ix.prosp.Org)+length(ix.prosp.Psych)+length(ix.prosp.Meds));
for snd=1:n.prosp.sub
    cnt=1;
    for jnd=[ix.prosp.Age ix.prosp.Gender ix.prosp.AoO]
        if jnd==ix.prosp.Gender
            data.prosp.Demo(snd,cnt)=strcmp(d{ix.prosp.Gender}(data.prosp.MRN(snd,2)),'F');
            cnt=cnt+2;
        else
            if d{jnd}(data.prosp.MRN(snd,2))>cutoff.year % onset is a year
                tmp.date=datetonum(d{ix.date}{data.prosp.MRN(snd,2)})+100000; % all current dates are >2000
                tmp.OnsetYear=(d{jnd}(data.prosp.MRN(snd,2))-cutoff.year)*10000+101; % transition all years to Jan 1st of that year
                data.prosp.Demo(snd,3)=floor((tmp.date-tmp.OnsetYear)/10000); % Duration is easier to calculate
                data.prosp.Demo(snd,cnt)=data.prosp.Demo(snd,1)-data.prosp.Demo(snd,3); % Transitioning to Onset
            else
                data.prosp.Demo(snd,cnt)=d{jnd}(data.prosp.MRN(snd,2));
            end
            cnt=cnt+1;
        end
    end
    cnt=1;
    for jnd=[ix.prosp.Org, ix.prosp.Psych, ix.prosp.Meds];
        data.pros(snd,cnt)=d{jnd}(data.prosp.MRN(snd,2));
        cnt=cnt+1;
    end
end
data.prosp.Demo(:,3)=data.prosp.Demo(:,1)-data.prosp.Demo(:,4); % Calculating Duration of Disease
if sum(data.prosp.Demo(:,3)<0)>1 % If ther are negative Durations, make them NaN
    data.prosp.Demo(find(data.prosp.Demo(:,3)<0),3)=NaN;
    fprintf('Some Onset - Age were negative, assuming this represents missing data\n');
end
heads.pros=heads.prosp([ix.prosp.Org, ix.prosp.Psych, ix.prosp.Meds]);
fprintf('Need to clean the prospective data matrix\n');
iy.nan=find(isnan(data.pros));
data.pros(iy.nan)=0;
ix.prosp.prev=find(sum(data.pros)>cutoff.prevalence);

% Load the diagnoses
fid=fopen(dirs.prospDx,'r'); % has the f/u column
d=textscan(fid,'%f %s %s %f %f %f %f %f %f %f %f %s %f %f %f %f %f %f %f %f %f %f %f %f','Delimiter',',','Headerlines',2);
fclose(fid);
ix.prosp.MRNDx=1;
ix.prosp.Dx=5;
ix.prosp.Dxdate=2;
data.prosp.Dx=ones(n.prosp.sub,2)*-7;
n.misDx=0;
for snd=1:n.prosp.sub
    iy.Dx=find(d{1}==data.prosp.MRN(snd,1));
    if isempty(iy.Dx)
        n.misDx=n.misDx+1;
        fprintf(['Missing Prosp Dx ' num2str(n.misDx) ':' num2str(data.prosp.MRN(snd,1)) '\n']);
        data.prosp.Dx(snd,:)=NaN;
    else
        if length(iy.Dx)==1
            data.prosp.Dx(snd,1)=d{ix.prosp.Dx}(iy.Dx);
        else
            % If multiple matches, find the most recent Dx
            dates=zeros(length(iy.Dx),1);
            for dnd=1:length(iy.Dx)
                dates(dnd)=datetonum(d{ix.prosp.Dxdate}{iy.Dx(dnd)});
            end
            [newdate, iy.new]=max(dates);
            data.prosp.Dx(snd,1)=d{ix.prosp.Dx}(iy.Dx(iy.new));
        end
    end
end
data.prosp.Dx(:,2)=((data.prosp.Dx(:,1)>0)+(data.prosp.Dx(:,1)<0)*-1).*(data.prosp.Dx(:,1)~=-5);

iy.nan=find(isnan(data.pros));
data.pros(iy.nan)=0;
iy.prosp.hazDx=find(data.prosp.Dx(:,2));
iy.prosp.incDx=find(data.prosp.Dx(:,1)==0);
iy.prosp.mixDx=find(data.prosp.Dx(:,1)==-5);
n.prosp.Dx=length(iy.prosp.hazDx);
n.prosp.inc=length(iy.prosp.incDx);
n.prosp.mix=length(iy.prosp.mixDx);
    
% Match Retrospective Columns to Prospective Columns
fid=fopen(dirs.ret2pro,'r');
d=textscan(fid,'%f %f %f %f','Delimiter',',','Headerlines',1);
fclose(fid);
data.testp=zeros(size(data.pros,1),size(data.retro,2));
for ind=1:length(d{1})
    if isnan(d{3}(ind))
        if ~isnan(d{2}(ind))
            if d{1}(ind)==7 % Cardiovascular
                data.testp(:,ind)=1*(data.pros(:,d{2}(ind))>0);
            else
                data.testp(:,ind)=data.pros(:,d{2}(ind));
            end
        end
    else
        data.testp(:,ind)=1*(data.pros(:,d{2}(ind))>0 | data.pros(:,d{3}(ind))>0 | data.pros(:,d{4}(ind))>0);
    end
end

fprintf('All Prospective Data Loaded\n');
% Output data for Weka
create_arff(dirs.prosparff,[data.prosp.Demo(iy.prosp.hazDx,1:2),data.pros(iy.prosp.hazDx,ix.prev)],1*(data.prosp.Dx(iy.prosp.hazDx,2)>0),2);

%% Classify the Prospective Data

% Use the Retrospective Data's Model
out.prosp.pred=zeros(n.prosp.Dx,2);
out.prosp.inc.pred=zeros(n.prosp.inc,2);
out.prosp.mix.pred=zeros(n.prosp.mix,2);
% 1: Prediction
% 2: Yhat
out.prosp.pred(:,2)  =glmval(out.mo,[data.prosp.Demo(iy.prosp.hazDx,1:2),data.testp(iy.prosp.hazDx,ix.prev)],'logit');
out.prosp.pred(:,1)  =round(out.prosp.pred(:,2))*2-1;
out.prosp.pred(:,5)  =1*(out.prosp.pred(:,1)==data.prosp.Dx(iy.prosp.hazDx,2));
out.prosp.inc.pred(:,2)=glmval(out.mo,[data.prosp.Demo(iy.prosp.incDx,1:2),data.testp(iy.prosp.incDx,ix.prev)],'logit');
out.prosp.inc.pred(:,1)=round(out.prosp.inc.pred(:,2))*2-1;
out.prosp.incpredES(1)=(sum(out.prosp.inc.pred(:,1)==1)+sum(out.inc.pred(:,1)==1))/(length(out.prosp.inc.pred)+length(out.inc.pred));
out.prosp.incpredES(2)=binoinv(0.025,length(out.prosp.inc.pred)+length(out.inc.pred),out.prosp.incpredES(1))/(length(out.prosp.inc.pred)+length(out.inc.pred));
out.prosp.incpredES(3)=binoinv(0.975,length(out.prosp.inc.pred)+length(out.inc.pred),out.prosp.incpredES(1))/(length(out.prosp.inc.pred)+length(out.inc.pred));
out.prosp.mix.pred(:,2)=glmval(out.mo,[data.prosp.Demo(iy.prosp.mixDx,1:2),data.testp(iy.prosp.mixDx,ix.prev)],'logit');
out.prosp.mix.pred(:,1)=round(out.prosp.mix.pred(:,2))*2-1;
out.prosp.mix.pred(:,5)=1*(out.prosp.mix.pred(:,1)==data.Dx(iy.prosp.mixDx,2));
out.prosp.mixpredES(1)=(sum(out.prosp.mix.pred(:,1)==1)+sum(out.mix.pred(:,1)==1))/(length(out.prosp.mix.pred)+length(out.mix.pred));
out.prosp.mixpredES(2)=binoinv(0.025,length(out.prosp.mix.pred)+length(out.mix.pred),out.prosp.mixpredES(1))/(length(out.prosp.mix.pred)+length(out.mix.pred));
out.prosp.mixpredES(3)=binoinv(0.975,length(out.prosp.mix.pred)+length(out.mix.pred),out.prosp.mixpredES(1))/(length(out.prosp.mix.pred)+length(out.mix.pred));

% Get Performance Statistics
out.prosp.ovac=mean(out.prosp.pred(:,5));
out.prosp.ovacCI=[binoinv(0.025,n.prosp.Dx,out.prosp.ovac)/n.prosp.Dx, binoinv(0.975,n.prosp.Dx,out.prosp.ovac)/n.prosp.Dx];
out.prosp.chac=max(1-mean(data.prosp.Dx(iy.prosp.hazDx,2)>0),mean(data.prosp.Dx(iy.prosp.hazDx,2)>0));
if out.prosp.ovac>out.prosp.chac
    out.prosp.ovp =(1-binocdf(sum(out.prosp.pred(:,5)),length(out.prosp.pred(:,5)),out.prosp.chac))*2;
    if out.prosp.ovp>0.05
       tmpp=(1-binocdf(sum(out.prosp.pred(:,5)),length(out.prosp.pred(:,5)),out.prosp.chac))*2;
       out.prosp.reqsamp=n.prosp.sub;
       while tmpp>0.05
           out.prosp.reqsamp=out.prosp.reqsamp+1;
           tmpp=(1-binocdf(floor(out.prosp.ovac*out.prosp.reqsamp),out.prosp.reqsamp,out.prosp.chac))*2;
       end
    end
else
    out.prosp.ovp =1;
end
iy.prosp.DxES  =find(data.prosp.Dx(iy.prosp.hazDx,2)>0);
iy.prosp.DxPNES=find(data.prosp.Dx(iy.prosp.hazDx,2)<0);
out.prosp.twobytwo=zeros(2,2);
out.prosp.twobytwo(1,1)=sum(out.prosp.pred(iy.prosp.DxES  ,5)); % ES correct
out.prosp.twobytwo(2,2)=sum(out.prosp.pred(iy.prosp.DxPNES,5)); % PNES correct
out.prosp.twobytwo(1,2)=length(iy.prosp.DxES  )-out.prosp.twobytwo(1,1); % False Neg Rate
out.prosp.twobytwo(2,1)=length(iy.prosp.DxPNES)-out.prosp.twobytwo(2,2); % False Pos Rate
out.prosp.sens=out.prosp.twobytwo(1,1)/length(iy.prosp.DxES  );
out.prosp.sensCI=[binoinv(0.025,length(iy.prosp.DxES),out.prosp.sens)/length(iy.prosp.DxES), binoinv(0.975,length(iy.prosp.DxES),out.prosp.sens)/length(iy.prosp.DxES)];
out.prosp.spec=out.prosp.twobytwo(2,2)/length(iy.prosp.DxPNES);
out.prosp.specCI=[binoinv(0.025,length(iy.prosp.DxPNES),out.prosp.spec)/length(iy.prosp.DxPNES), binoinv(0.975,length(iy.prosp.DxPNES),out.prosp.spec)/length(iy.prosp.DxPNES)];
out.prosp.PPV =out.prosp.twobytwo(1,1)/(out.prosp.twobytwo(1,1)+out.prosp.twobytwo(2,1));
out.prosp.NPV =out.prosp.twobytwo(2,2)/(out.prosp.twobytwo(2,2)+out.prosp.twobytwo(1,2));

ix.prosp.thresh=unique(out.prosp.pred(:,2));
n.prosp.thresh =length(ix.prosp.thresh);
out.prosp.ROC  =zeros(n.prosp.thresh,2);
out.prosp.AUC  =0;
data.prosp.BinDx=1*(data.prosp.Dx(iy.prosp.hazDx,2)>0);
for tnd=1:n.prosp.thresh
    iy.hi=find(out.prosp.pred(:,2)>=ix.prosp.thresh(tnd));
    iy.lo=setdiff(1:n.prosp.Dx,iy.hi);
    out.prosp.ROC(tnd,1)=length(intersect(iy.hi,iy.prosp.DxES))/length(iy.prosp.DxES); % True Positive Rate
    out.prosp.ROC(tnd,2)=1-length(intersect(iy.lo,iy.prosp.DxPNES))/length(iy.prosp.DxPNES); % False Pos Rate or 1-spec
    if tnd>1
        out.prosp.AUC=out.prosp.AUC+(1-out.prosp.ROC(tnd,2))*(out.prosp.ROC(tnd-1,1)-out.prosp.ROC(tnd,1));
    end
end

fprintf('Retrospective Model Applied to Prospective Data\n');

%% Permutation Testing
if doperms
    fprintf('Doing Permutation Testing\n');
    perms.pred    =zeros(n.prosp.Dx,3,n.perms);
    perms.mo      =zeros(size(out.mo,1),n.perms);
    perms.clas    =zeros(n.retro,2,n.perms);
    perms.ovac    =zeros(n.perms,1);
    perms.twobytwo=zeros(2,2,n.perms);
    perms.ROC     =zeros(n.prosp.Dx,2,n.perms);
    perms.AUC     =zeros(n.perms,1);
    perms.sens    =perms.AUC;
    perms.spec    =perms.AUC;
    perms.PPV     =perms.AUC;
    perms.NPV     =perms.AUC;
    for pnd=1:n.perms
        if n.perms>999
            if ~isempty(intersect(pnd,n.perms/10:n.perms/10:n.perms));
                fprintf(['Perm ' num2str(pnd) '/' num2str(n.perms) '\n']);
            end
        end
        r=randperm(n.retro);
        perms.clas(:,:,pnd)=data.Dx(r,:);
        piy.hazDx=find(perms.clas(:,2,pnd));
%         piy.incDx=find(perms.clas(:,1,pnd)==0);
%         piy.mixDx=find(perms.clas(:,1,pnd)==-5);
        warning off
        [perms.mo(:,pnd),tmp.dev,tmp.stats]=glmfit([data.Demo(piy.hazDx,1:2),data.retro(piy.hazDx,ix.prev)],1*(perms.clas(piy.hazDx,2,pnd)>0),'binomial','link','logit');
        warning on
        perms.pred(:,2,pnd)=glmval(perms.mo(:,pnd),[data.prosp.Demo(iy.prosp.hazDx,1:2),data.testp(iy.prosp.hazDx,ix.prev)],'logit');
        perms.pred(:,1,pnd)=round(perms.pred(:,2,pnd))*2-1;
        perms.pred(:,3,pnd)=1*(perms.pred(:,1,pnd)==data.prosp.Dx(iy.prosp.hazDx,2));

        perms.ovac(pnd)=mean(perms.pred(:,3,pnd));
        perms.twobytwo(1,1,pnd)=sum(perms.pred(iy.prosp.DxES  ,3,pnd)); % ES correct
        perms.twobytwo(2,2,pnd)=sum(perms.pred(iy.prosp.DxPNES,3,pnd)); % PNES correct
        perms.twobytwo(1,2,pnd)=length(iy.prosp.DxES  )-perms.twobytwo(1,1,pnd); % False Neg Rate
        perms.twobytwo(2,1,pnd)=length(iy.prosp.DxPNES)-perms.twobytwo(2,2,pnd); % False Pos Rate
        perms.sens(pnd)=perms.twobytwo(1,1,pnd)/length(iy.prosp.DxES  );
        perms.spec(pnd)=perms.twobytwo(2,2,pnd)/length(iy.prosp.DxPNES);
        perms.PPV (pnd)=perms.twobytwo(1,1,pnd)/(perms.twobytwo(1,1,pnd)+perms.twobytwo(2,1,pnd));
        perms.NPV (pnd)=perms.twobytwo(2,2,pnd)/(perms.twobytwo(2,2,pnd)+perms.twobytwo(1,2,pnd));
        
        perms.thresh=sort(perms.pred(:,2,pnd));
        for tnd=1:n.prosp.Dx
            iy.hi=find(perms.pred(:,2)>=perms.thresh(tnd));
            iy.lo=setdiff(1:n.prosp.Dx,iy.hi);
            perms.ROC(tnd,1,pnd)=length(intersect(iy.hi,iy.prosp.DxES))/length(iy.prosp.DxES); % True Positive Rate
            perms.ROC(tnd,2,pnd)=1-length(intersect(iy.lo,iy.prosp.DxPNES))/length(iy.prosp.DxPNES); % False Pos Rate or 1-spec
            if tnd>1
                perms.AUC(pnd)=perms.AUC(pnd)+(1-perms.ROC(tnd,2,pnd))*(perms.ROC(tnd-1,1,pnd)-perms.ROC(tnd,1,pnd));
            end
        end
    end 
    fprintf('To do: Model and Performance Statistics by Empirical Probabilities\n');
    fprintf('Permutation Testing Done\n');
end

%% ROC Figure
figure;
pl1=plot(out.ROC(:,2),out.ROC(:,1),'LineWidth',2,'color',[0 0 0]); % Retrospective
axis square
set(gca,'fontsize',14);
ylabel('True Positive Rate');
xlabel('False Positive Rate');
percs={'0%','20%','40%','60%','80%','100%'};
set(gca,'ytick',0:0.2:1,'yticklabel',percs);
set(gca,'xtick',0:0.2:1,'xticklabel',percs);
hold on
pl2=plot(out.prosp.ROC(:,2),out.prosp.ROC(:,1),'LineWidth',2,'color',[0 0 1]); % Prospective
set(pl1,'DisplayName','Retrospective');
set(pl2,'DisplayName','Prospective');
pl3=plot(0:0.1:1,0:0.1:1,'LineWidth',2,'color',[0.4 0.4 0.4]);
set(pl3,'DisplayName','Chance');
legend1 = legend(gca,'show');
if doperms
    for pnd=1:n.perms
        pl3=plot(perms.ROC(:,2,pnd),perms.ROC(:,1,pnd),'LineWidth',1,'color',[0.4 0.4 0.4]);
        if pnd==1
            set(pl3,'DisplayName','Chance');
            legend1 = legend(gca,'show');
        end
    end
end
hold off

%% Performance Figure
% Steal from RoS but compress it
summary.perf=zeros(5,3);
% 1: Acc
% 2: Sens
% 3: Spec
% 4: PPV
% 5: PPV
% Index 2: Mean, LB, UB
summary.perf(:,1)=[out.prosp.ovac, out.prosp.sens, out.prosp.spec, out.prosp.PPV, out.prosp.NPV];
summary.perf(1,2)=binoinv(0.025,n.prosp.Dx,out.prosp.ovac)/n.prosp.Dx;
summary.perf(1,3)=binoinv(0.975,n.prosp.Dx,out.prosp.ovac)/n.prosp.Dx;
summary.perf(2,2)=binoinv(0.025,sum(out.prosp.twobytwo(1,:)),out.prosp.sens)/sum(out.prosp.twobytwo(1,:));
summary.perf(2,3)=binoinv(0.975,sum(out.prosp.twobytwo(1,:)),out.prosp.sens)/sum(out.prosp.twobytwo(1,:));
summary.perf(3,2)=binoinv(0.025,sum(out.prosp.twobytwo(2,:)),out.prosp.spec)/sum(out.prosp.twobytwo(2,:));
summary.perf(3,3)=binoinv(0.975,sum(out.prosp.twobytwo(2,:)),out.prosp.spec)/sum(out.prosp.twobytwo(2,:));
summary.perf(4,2)=binoinv(0.025,sum(out.prosp.twobytwo(:,1)),out.prosp.PPV)/sum(out.prosp.twobytwo(:,1));
summary.perf(4,3)=binoinv(0.975,sum(out.prosp.twobytwo(:,1)),out.prosp.PPV)/sum(out.prosp.twobytwo(:,1));
summary.perf(5,2)=binoinv(0.025,sum(out.prosp.twobytwo(:,2)),out.prosp.NPV)/sum(out.prosp.twobytwo(:,2));
summary.perf(5,3)=binoinv(0.975,sum(out.prosp.twobytwo(:,2)),out.prosp.NPV)/sum(out.prosp.twobytwo(:,2));
summary.chan=zeros(5,1);
summary.chan([1,4])=max(length(iy.prosp.DxES),length(iy.prosp.DxPNES))/n.prosp.Dx;
summary.chan([2,3,5])=0.5;

figure
bar3=barh(summary.perf(5:-1:1,1),'BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
set(gca,'fontsize',16);
sumstats={'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'};
set(gca,'ytick',1:5,'yticklabel',sumstats);
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
% set(bar3(1),'FaceColor',[0.70 0.3 1],...
%     'DisplayName','RoS+Sex+Comorbid');
% legend1 = legend(gca,'show');
hold on
cha3=barh(summary.chan(5:-1:1),'BarWidth',1,'FaceColor',[0.8 0.8 0.8],'EdgeColor',[1 1 1]);
cnt=1;
for jnd=5:-1:1
    ebs3=errbar(summary.perf(jnd,1),cnt,abs(summary.perf(jnd,1)-summary.perf(jnd,2)),abs(summary.perf(jnd,1)-summary.perf(jnd,3)),'horiz','LineWidth',3,'Color',[0 0 0]);
    cnt=cnt+1;
end
hold off

fid=fopen(dirs.perffile,'w');
fprintf(fid,'Summary Statistic,Prospective Performance,95 CI,Chance\n');
for ind=1:5
    fprintf(fid,[sumstats{6-ind} ',' num2str(round(100*summary.perf(ind,1),0)) ',' num2str(floor(100*summary.perf(ind,2))) '--' num2str(ceil(100*summary.perf(ind,3))) ',' num2str(round(100*summary.chan(ind))) '\n']);
end
fclose(fid);

%% Data Figures
n.class=5;
data.all.compiled=[data.retro;data.testp];
data.all.Dx      =[data.Dx;data.prosp.Dx];
ix.all.classid=cell(n.class,1);
ix.all.classid{1}=find(data.all.Dx(:,1)>1); % ES
ix.all.classid{2}=find(data.all.Dx(:,1)==-1); % PSLE
ix.all.classid{3}=find(data.all.Dx(:,1)==0); % Inconclusive
ix.all.classid{4}=find(data.all.Dx(:,1)==-5); % Mixed
ix.all.classid{5}=find(data.all.Dx(:,1)==-2); % PNES
ix.retvpro.classid=cell(n.class,2);
ix.retvpro.classid{1,1}=find(data.Dx(:,1)>1); % ES
ix.retvpro.classid{2,1}=find(data.Dx(:,1)==-1); % PSLE
ix.retvpro.classid{3,1}=find(data.Dx(:,1)==0); % Inconclusive
ix.retvpro.classid{4,1}=find(data.Dx(:,1)==-5); % Mixed
ix.retvpro.classid{5,1}=find(data.Dx(:,1)==-2); % PNES
ix.retvpro.classid{1,2}=find(data.prosp.Dx(:,1)>1); % ES
ix.retvpro.classid{2,2}=find(data.prosp.Dx(:,1)==-1); % PSLE
ix.retvpro.classid{3,2}=find(data.prosp.Dx(:,1)==0); % Inconclusive
ix.retvpro.classid{4,2}=find(data.prosp.Dx(:,1)==-5); % Mixed
ix.retvpro.classid{5,2}=find(data.prosp.Dx(:,1)==-2); % PNES

% Continuous 5-class Variables
ix.contfigs=[1,22,25:31];
maxpt=zeros(size(data.retro,2),1);
maxpt(1)=10;
maxpt(22)=4;
maxpt(25)=6;
maxpt(26)=10;
maxpt(27)=6;
maxpt(28)=5;
maxpt(29)=11;
maxpt(30)=5;
maxpt(31)=5;
for fnd=ix.contfigs
    if maxpt(fnd)>0
        datafigs.ncomorbid=0:maxpt(fnd);
    else
        datafigs.ncomorbid=0:max(data.all.compiled(:,fnd));
    end
    datafigs.com5class=zeros(5,length(datafigs.ncomorbid));
    cnt=1;
    for ind=datafigs.ncomorbid
        for jnd=1:5
            if fnd==1 || fnd==2
                if ind<maxpt(fnd)
                    datafigs.com5class(jnd,cnt)=sum(data.all.compiled(ix.all.classid{jnd},fnd)==ind);
                else
                    datafigs.com5class(jnd,cnt)=sum(data.all.compiled(ix.all.classid{jnd},fnd)>=ind);
                end
            else
                datafigs.com5class(jnd,cnt)=sum(data.all.compiled(ix.all.classid{jnd},fnd)==ind);
            end
        end
        cnt=cnt+1;
    end
    datafigs.com5sum=sum(datafigs.com5class,1);
    datafigs.com5class=datafigs.com5class./repmat(sum(datafigs.com5class,1),[n.class 1]);
    
    figure;
    bar5=bar(datafigs.ncomorbid,datafigs.com5class','stacked','BarWidth',1);
    set(gca,'fontsize',18);
    title('All Data');
    if fnd==1
        xlabel('Number of Medical Comorbidities');
        set(gca,'xlim',[-0.5 length(datafigs.ncomorbid)-0.5],'xticklabel',{'0','1','2','3','4','5','6','7','8','9','>10'});
    elseif fnd==22
        xlabel('Number of Psychiatric Comorbidities');
        set(gca,'xlim',[-0.5 length(datafigs.ncomorbid)-0.5],'xticklabel',{'0','1','2','3','>4'});
    elseif fnd==25
        xlabel('Number of Current ASMs');
        set(gca,'xlim',[-0.5 length(datafigs.ncomorbid)-0.5],'xticklabel',{'0','1','2','3','4,','5','>6'});
    else
        xlabel(heads.retro{fnd});
        set(gca,'xlim',[-0.5 length(datafigs.ncomorbid)-0.5]);%,'xticklabel',{'0','1','2','3','4','5','6','7','8','9','>10'});
    end
    ylabel('Percent of All Patients');
    set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
end

% Binary 5 class figures
ix.binfigs=setdiff(ix.prev,ix.contfigs);
n.bin=length(ix.binfigs);
datafigs.bin5class=zeros(5,n.bin);
cnt=0;
for fnd=ix.binfigs
    cnt=cnt+1;
    for jnd=1:5
        datafigs.bin5class(jnd,cnt)=sum(data.all.compiled(ix.all.classid{jnd},fnd));
    end
end
datafigs.bin5sum=sum(datafigs.bin5class,1);
datafigs.bin5class=datafigs.bin5class./repmat(sum(datafigs.bin5class,1),[n.class 1]);
    
figure;
bar5=barh(1:n.bin,datafigs.bin5class(:,end:-1:1)','stacked','BarWidth',1);
set(gca,'fontsize',18);
title('All Data');
set(gca,'ylim',[0.5 n.bin+0.5],'ytick',1:n.bin,'yticklabel',{heads.retro{ix.binfigs(end:-1:1)}}); %,'XTickLabelRotation',90);
xlabel('Percent of All Patients');
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
    

%% Table 1
% Age, Sex, Delay to Diagnosis
data.all.Demo=[data.Demo;data.prosp.Demo];
% Class information
data.all.class=data.all.Dx(:,1);
%simplify class
fprintf('Simplying all ES to one type\n');
tmp=find(data.all.class>0);
data.all.class(tmp)=1;

summary.all.classes=zeros(n.class+2,5,6);
% Index 2
% 1: Class value
% 2: n
% 3: Age
% 4: Sex
% 5: Delay
% Index 3
% 1: Mean
% 2: Min
% 3: Max
% 4: STD
% 5: 95% CI LB
% 6: 95% CI UB
ix.Demo=1:3;
tmp=unique(data.all.class);
tmp2=find(~isnan(tmp));
data.classes=tmp(tmp2);
for ind=1:size(summary.all.classes,3)
    summary.all.classes(1:n.class,1,ind)=tmp(tmp2);
end
summary.all.classes(n.class+1,1,:)=411; % all
summary.all.classes(n.class+2,1,:)=5; % TLE

ix.all.classid=cell(n.class+2,1);
for ind=1:n.class+2
    if ind>n.class
        if ind==n.class+1
            ix.all.classid{ind}=ix.all.classid{1};
            for jnd=2:n.class
                ix.all.classid{ind}=union(ix.all.classid{ind},ix.all.classid{jnd});
            end
        else
            ix.all.classid{ind}=find([data.all.Dx(1:n.retro,1)==7;data.all.Dx(n.retro+1:end,1)==5]);
        end
    else
        ix.all.classid{ind}=find(data.all.class==summary.all.classes(ind,1));
    end
    summary.all.classes(ind,2,:)=length(ix.all.classid{ind});
    for jnd=ix.Demo
        summary.all.classes(ind,jnd+2,1)=nanmean(data.all.Demo(ix.all.classid{ind},jnd));
        summary.all.classes(ind,jnd+2,2)=min(data.all.Demo(ix.all.classid{ind},jnd));
        summary.all.classes(ind,jnd+2,3)=max(data.all.Demo(ix.all.classid{ind},jnd));
        summary.all.classes(ind,jnd+2,4)=nanstd(data.all.Demo(ix.all.classid{ind},jnd));
        summary.all.classes(ind,jnd+2,5)=summary.all.classes(ind,jnd+2,1)-1.96*summary.all.classes(ind,jnd+2,4)/sqrt(summary.all.classes(ind,2,1)); 
        summary.all.classes(ind,jnd+2,6)=summary.all.classes(ind,jnd+2,1)+1.96*summary.all.classes(ind,jnd+2,4)/sqrt(summary.all.classes(ind,2,1)); 
    end
end

% Write it!
fid=fopen(dirs.table1,'w');
fprintf(fid,', ,Age,Sex,Delay\n');
fprintf(fid,'Class,Count,Min (95CI) Max,Mean,Min (95CI) Max\n');
for ind=[1:n.class n.class+2 n.class+1]
    fprintf(fid,[num2str(summary.all.classes(ind,1,1)) ',' num2str(summary.all.classes(ind,2,1)) ',']);
    for jnd=3:5
        if jnd==4
            fprintf(fid,[num2str(round(100*summary.all.classes(ind,jnd,1))) ',']);
        else
            fprintf(fid,[num2str(summary.all.classes(ind,jnd,2)) ' (' num2str(floor(summary.all.classes(ind,jnd,5))) '-' num2str(ceil(summary.all.classes(ind,jnd,6))) ') ' num2str(summary.all.classes(ind,jnd,3)) ',']);
        end
    end
    fprintf(fid,'\n');
end
fclose(fid);

%% Supplemental Table 1 - Splitting Retrospective and Prospective
% Age, Sex, Delay to Diagnosis
% Class information
data.class=data.Dx(:,1);
data.prosp.class=data.prosp.Dx(:,1);
%simplify class
tmp=find(data.class>0);
data.class(tmp)=1;
tmp=find(data.prosp.class>0);
data.prosp.class(tmp)=1;

summary.retvpro.classes=zeros(n.class+2,5,6,2);
% Index 2
% 1: Class value
% 2: n
% 3: Age
% 4: Sex
% 5: Delay
% Index 3
% 1: Mean
% 2: Min
% 3: Max
% 4: STD
% 5: 95% CI LB
% 6: 95% CI UB
% Index 4
% 1: Retrospective
% 2: Prospective
ix.Demo=1:3;
tmp=unique(data.class);
tmp2=find(~isnan(tmp));
data.classes=tmp(tmp2);
for ind=1:size(summary.all.classes,3)
    summary.retvpro.classes(1:n.class,1,ind,:)=repmat(tmp(tmp2),[1 2]);
end
summary.retvpro.classes(n.class+1,1,:,:)=411; % all
summary.retvpro.classes(n.class+2,1,:,1)=7; % TLE
summary.retvpro.classes(n.class+2,1,:,2)=5;

% ix.retvpro.classid=cell(n.class+2,2);
clear tmp
for rnd=1:2
    for ind=1:n.class+2
        if ind>n.class
            if ind==n.class+1
                ix.retvpro.classid{ind,rnd}=ix.retvpro.classid{1,rnd};
                for jnd=2:n.class
                    ix.retvpro.classid{ind,rnd}=union(ix.retvpro.classid{ind,rnd},ix.retvpro.classid{jnd,rnd});
                end
            else
                if rnd==1
                    ix.retvpro.classid{ind,rnd}=find(data.Dx(:,1)==7); % TLE
                else
                    ix.retvpro.classid{ind,rnd}=find(data.prosp.Dx(:,1)==5); % TLE
                end
            end
        else
            % these were created above
%             ix.retvpro.classid{ind,rnd}=find(data.all.class==summary.all.classes(ind,1));
        end
        summary.retvpro.classes(ind,2,:,rnd)=length(ix.retvpro.classid{ind,rnd});
        for jnd=ix.Demo
            if ~isempty(ix.retvpro.classid{ind,rnd})
                if rnd==1
                    tmp.source=data.Demo(ix.retvpro.classid{ind,rnd},jnd);
                else
                    tmp.source=data.prosp.Demo(ix.retvpro.classid{ind,rnd},jnd);
                end
                summary.retvpro.classes(ind,jnd+2,1,rnd)=nanmean(tmp.source);
                summary.retvpro.classes(ind,jnd+2,2,rnd)=min(tmp.source);
                summary.retvpro.classes(ind,jnd+2,3,rnd)=max(tmp.source);
                summary.retvpro.classes(ind,jnd+2,4,rnd)=nanstd(tmp.source);
                summary.retvpro.classes(ind,jnd+2,5,rnd)=summary.retvpro.classes(ind,jnd+2,1,rnd)-1.96*summary.retvpro.classes(ind,jnd+2,4,rnd)/sqrt(summary.retvpro.classes(ind,2,1,rnd));
                summary.retvpro.classes(ind,jnd+2,6,rnd)=summary.retvpro.classes(ind,jnd+2,1,rnd)+1.96*summary.retvpro.classes(ind,jnd+2,4,rnd)/sqrt(summary.retvpro.classes(ind,2,1,rnd));
            end
        end
    end
end

% Write it!
fid=fopen(dirs.Stable1,'w');
fprintf(fid,',,,Age,Sex,Delay\n');
fprintf(fid,'Class,Dataset,Count,Min (95CI) Max,Mean,Min (95CI) Max\n');
for ind=[1:n.class n.class+2 n.class+1]
    fprintf(fid,[num2str(summary.retvpro.classes(ind,1,1,rnd)) ',']);
    for rnd=1:2
        if rnd==1
            fprintf(fid,'Retro,');
        else
            fprintf(fid,',Prosp,');
        end
        fprintf(fid,[num2str(summary.retvpro.classes(ind,2,1,rnd)) ',']);
        for jnd=3:5
            if jnd==4
                fprintf(fid,[num2str(round(100*summary.retvpro.classes(ind,jnd,1,rnd))) ',']);
            else
                fprintf(fid,[num2str(summary.retvpro.classes(ind,jnd,2,rnd)) ' (' num2str(floor(summary.retvpro.classes(ind,jnd,5,rnd))) '-' num2str(ceil(summary.retvpro.classes(ind,jnd,6,rnd))) ') ' num2str(summary.retvpro.classes(ind,jnd,3,rnd)) ',']);
            end
        end
        fprintf(fid,'\n');
    end
end
fclose(fid);

%% Descriptive models
% Describe 5-class trends
% (e.g. hypothyroidism assoc with PNES vs ES when control for # total comorbid)
ix.NumComorb  =1;
ix.Comorb     =[2:21, 23,24];
n.Comorb      =length(ix.Comorb);

data.all.DxIx=zeros(length(data.all.compiled),n.class);
for ind=1:n.class-1
    data.all.DxIx(ix.all.classid{ind},ind)=1;
end
data.all.DxIx(ix.all.classid{7},n.class)=1;

ix.NumFailed=26;
modeldata.Xc=[data.all.DxIx(ix.all.classid{6},:),data.all.Demo(ix.all.classid{6},1:2),data.all.compiled(ix.all.classid{6},ix.NumComorb)];
modeldata.XcF=[data.all.DxIx(ix.all.classid{6},:),data.all.Demo(ix.all.classid{6},1:2),data.all.compiled(ix.all.classid{6},ix.NumComorb),data.all.compiled(ix.all.classid{6},ix.NumFailed)];
heads.varnames={'ES','Mixed','PNES','PSLE','Inc','TLE','Age','Sex','Comorb'};
heads.vars    ={'b','se','p'};
n.dummy=n.class+1;
modeldata.Xdummy=zeros(n.class+1,size(modeldata.Xc,2)); % For predicting the average value of each class
tmpeye=eye(n.class+1);
modeldata.Xdummy(1:n.class+1,1:n.class)=tmpeye(:,2:end); % indicator for each class
modeldata.Xdummy(:,n.class+1)=mean(modeldata.Xc(:,n.class+1)); % Age
cnt=0;
summary.bs=zeros(n.Comorb,size(modeldata.Xc,2)+1,4); % Mean, SE, p, df
summary.devs=zeros(n.Comorb,2);
summary.pred=zeros(size(data.retro,2),size(modeldata.Xdummy,1),3); % Mean, LB, UB
for ind=ix.Comorb
    cnt=cnt+1;
    modeldata.Yc=data.all.compiled(ix.all.classid{6},ind); 
    [summary.bs(cnt,:,1),summary.devs(cnt,1),statstmp]=glmfit(modeldata.Xc,modeldata.Yc,'binomial','link','logit');
    summary.bs(cnt,:,2)=statstmp.se;
    summary.bs(cnt,:,3)=statstmp.p;
    summary.bs(cnt,:,4)=length(statstmp.beta)-1;
    [tmp1,summary.devs(cnt,2),tmp2]=glmfit(ones(size(modeldata.Xc,1),1),modeldata.Yc,'binomial','link','logit','constant','off');
    [summary.pred(ind,:,1),summary.pred(ind,:,2),summary.pred(ind,:,3)]=glmval(summary.bs(cnt,:,1)',modeldata.Xdummy,'logit',statstmp);
    % error bars are for one subject, transforming them to the correct
    % number of subjects
    tmps.raw  =[summary.pred(ind,:,1);summary.pred(ind,:,1)-summary.pred(ind,:,2);summary.pred(ind,:,1)+summary.pred(ind,:,3)];
    tmps.trans=log(tmps.raw./(1-tmps.raw));
%     tmps.SEL   =(tmps.trans(1,:)-tmps.trans(2,:))./sqrt(summary.all.classes([1:5,7],2,1))';
% the above line is for debugging, since the model is a transformed normal,
% the SE upper and SE lower should match
    tmps.SE   =(tmps.trans(3,:)-tmps.trans(1,:))./sqrt(summary.all.classes([1:5,7],2,1))';
    tmps.trans(2,:)=tmps.trans(1,:)-tmps.SE;
    tmps.trans(3,:)=tmps.trans(1,:)+tmps.SE;
    summary.pred(ind,:,[2,3])=(ones(2,n.class+1)./(1+exp(-tmps.trans([2,3],:))))';
end

ix.Counts     =[1,22,25:size(data.retro,2)];
ix.failedtype =27:28;
n.Counts      =length(ix.Counts);
summary.cnt.bs=zeros(n.Counts,size(modeldata.Xc,2)+1,4);
summary.cnt.devs=zeros(n.Counts,2);
cnt2=0;
for ind=ix.Counts
    cnt2=cnt2+1;
    modeldata.Yc=data.all.compiled(ix.all.classid{6},ind); 
    [summary.cnt.bs(cnt2,:,1),summary.cnt.devs(cnt2),statstmp]=glmfit(modeldata.Xc,modeldata.Yc,'poisson','link','log');
    summary.cnt.bs(cnt2,:,2)=statstmp.se;
    summary.cnt.bs(cnt2,:,3)=statstmp.p;
    summary.cnt.bs(cnt2,:,4)=length(statstmp.beta)-1;
    [tmp1,summary.cnt.devs(cnt2,2),tmp2]=glmfit(ones(size(modeldata.Xc,1),1),modeldata.Yc,'poisson','link','log','constant','off');
    [summary.pred(ind,:,1),summary.pred(ind,:,2),summary.pred(ind,:,3)]=glmval(summary.cnt.bs(cnt2,:,1)',modeldata.Xdummy,'log',statstmp);
    tmps.raw  =[summary.pred(ind,:,1);summary.pred(ind,:,1)-summary.pred(ind,:,2);summary.pred(ind,:,1)+summary.pred(ind,:,3)];
    tmps.trans=exp(tmps.raw);
    tmps.SE   =tmps.trans(3,:)-tmps.trans(1,:);
%     tmps.SE   =(tmps.trans(3,:)-tmps.trans(1,:))./sqrt(summary.all.classes([1:5,7],2,1))';
    tmps.trans(2,:)=tmps.trans(1,:)-tmps.SE;
    tmps.trans(3,:)=tmps.trans(1,:)+tmps.SE;
    summary.pred(ind,:,[2,3])=log(tmps.trans([2,3],:))';
end

summary.cnt.bsF=zeros(2,size(modeldata.XcF,2)+1,4);
summary.cnt.devsF=zeros(length(ix.failedtype),2);
cnt2=0; %find(ix.failedtype(1)==ix.Counts)-1;
modeldata.XdummyF=[modeldata.Xdummy,ones(size(modeldata.Xdummy,1),1)*mean(data.all.compiled(ix.all.classid{6},ix.NumFailed))];
% fprintf('Note cnt2 is incorrect now!\n');
fprintf('Note Overwriting Why Failed Prediction with Controlling for Number Failed\n');
for ind=ix.failedtype
    cnt2=cnt2+1;
    modeldata.Yc=data.all.compiled(ix.all.classid{6},ind); 
    [summary.cnt.bsF(cnt2,:,1),summary.cnt.devsF(cnt2),statstmp]=glmfit(modeldata.XcF,modeldata.Yc,'poisson','link','log');
    summary.cnt.bsF(cnt2,:,2)=statstmp.se;
    summary.cnt.bsF(cnt2,:,3)=statstmp.p;
    summary.cnt.bsF(cnt2,:,4)=length(statstmp.beta)-1;
    [tmp1,summary.cnt.devsF(cnt2,2),tmp2]=glmfit(ones(size(modeldata.Xc,1),1),modeldata.Yc,'poisson','link','log','constant','off');
    [summary.pred(ind,:,1),summary.pred(ind,:,2),summary.pred(ind,:,3)]=glmval(summary.cnt.bsF(cnt2,:,1)',modeldata.XdummyF,'log',statstmp);
    tmps.raw  =[summary.pred(ind,:,1);summary.pred(ind,:,1)-summary.pred(ind,:,2);summary.pred(ind,:,1)+summary.pred(ind,:,3)];
    tmps.trans=exp(tmps.raw);
    tmps.SE   =tmps.trans(3,:)-tmps.trans(1,:);
%     tmps.SE   =(tmps.trans(3,:)-tmps.trans(1,:))./sqrt(summary.all.classes([1:5,7],2,1))';
    tmps.trans(2,:)=tmps.trans(1,:)-tmps.SE;
    tmps.trans(3,:)=tmps.trans(1,:)+tmps.SE;
    summary.pred(ind,:,[2,3])=log(tmps.trans([2,3],:))';
end

fid=fopen(dirs.Descrip,'w');
fprintf(fid,'Predicted Dx,Summary Stat,');
for jnd=1:length(heads.varnames)
    fprintf(fid,[heads.varnames{jnd} ',']);
end
fprintf(fid,'NumFailed,dev0-dev,df,p');
fprintf(fid,'\n');
for znd=1:length(ix.Comorb)
    for ind=1:3
        if ind==1
            fprintf(fid,[heads.retro{ix.Comorb(znd)} ',']);
        else
            fprintf(fid,',');
        end
        fprintf(fid,heads.vars{ind});
        for jnd=1:length(heads.varnames)
            fprintf(fid,[',' num2str(summary.bs(znd,jnd,ind))]);
        end
        if ind==1
            fprintf(fid,[',,' num2str(summary.devs(znd,2)-summary.devs(znd,1)) ',']);
            fprintf(fid,[num2str(summary.bs(znd,jnd,4)) ',' num2str(1-chi2cdf(summary.devs(znd,2)-summary.devs(znd,1),summary.bs(znd,jnd,4)))]); 
        end
        fprintf(fid,'\n');
    end
end
for znd=1:length(ix.Counts)
    for ind=1:3
        if ind==1
            fprintf(fid,[heads.retro{ix.Counts(znd)} ',']);
        else
            fprintf(fid,',');
        end
        fprintf(fid,heads.vars{ind});
        if intersect(ix.Counts(znd),ix.failedtype)
            znd2=znd-find(ix.failedtype(1)==ix.Counts)+1;
            for jnd=1:length(heads.varnames)+1
                fprintf(fid,[',' num2str(summary.cnt.bsF(znd2,jnd,ind))]);
            end
            if ind==1
                fprintf(fid,[',' num2str(summary.cnt.devsF(znd2,2)-summary.cnt.devsF(znd2,1)) ',']);
                fprintf(fid,[num2str(summary.cnt.bsF(znd2,jnd,4)) ',' num2str(1-chi2cdf(summary.cnt.devsF(znd2,2)-summary.cnt.devsF(znd2,1),summary.cnt.bsF(znd2,jnd,4)))]);
            end
        else
            for jnd=1:length(heads.varnames)
                fprintf(fid,[',' num2str(summary.cnt.bs(znd,jnd,ind))]);
            end
            fprintf(fid,',');
            if ind==1
                fprintf(fid,[',' num2str(summary.cnt.devs(znd,2)-summary.cnt.devs(znd,1)) ',']);
                fprintf(fid,[num2str(summary.cnt.bs(znd,jnd,4)) ',' num2str(1-chi2cdf(summary.cnt.devs(znd,2)-summary.cnt.devs(znd,1),summary.cnt.bs(znd,jnd,4)))]);
            end
        end
        fprintf(fid,'\n');
    end
end
fclose(fid);

modeldata.Xc2=[data.all.DxIx(ix.all.classid{6},:),data.all.Demo(ix.all.classid{6},1:2)];
heads.varnames2={'Int','Mixed','PNES','PSLE','Inc','TLE','Age','Sex'};
heads.vars    ={'b','se','p'};
cnt=0;
summary.bs2=zeros(n.Comorb,size(modeldata.Xc2,2)+1,4); % Mean, SE, p
summary.devs2=zeros(n.Comorb,2);
warning off
for ind=ix.Comorb
    cnt=cnt+1;
    modeldata.Yc=data.all.compiled(ix.all.classid{6},ind); 
    [summary.bs2(cnt,:,1),summary.devs2(cnt,1),statstmp]=glmfit(modeldata.Xc2,modeldata.Yc,'binomial','link','logit');
    summary.bs2(cnt,:,2)=statstmp.se;
    summary.bs2(cnt,:,3)=statstmp.p;
    summary.bs2(cnt,:,4)=length(statstmp.beta)-1;
    [tmp1,summary.devs2(cnt,2),tmp2]=glmfit(ones(size(modeldata.Xc2,1),1),modeldata.Yc,'binomial','link','logit','constant','off');
end
warning on
ix.Counts     =[1,22,25:size(data.retro,2)];
n.Counts      =length(ix.Counts);
summary.cnt.bs2=zeros(n.Counts,size(modeldata.Xc2,2)+1,4);
summary.cnt.devs2=zeros(n.Counts,2);
cnt2=0;
for ind=ix.Counts
    cnt2=cnt2+1;
    modeldata.Yc=data.all.compiled(ix.all.classid{6},ind); 
    [summary.cnt.bs2(cnt2,:,1),summary.cnt.devs2(cnt2,1),statstmp]=glmfit(modeldata.Xc2,modeldata.Yc,'poisson','link','log');
    summary.cnt.bs2(cnt2,:,2)=statstmp.se;
    summary.cnt.bs2(cnt2,:,3)=statstmp.p;
    summary.cnt.bs2(cnt2,:,4)=length(statstmp.beta)-1;
    [tmp1,summary.cnt.devs2(cnt2,2),tmp2]=glmfit(ones(size(modeldata.Xc2,1),1),modeldata.Yc,'poisson','link','log','constant','off');
end

fid=fopen(dirs.Descrip2,'w');
fprintf(fid,'Predicted Dx,Summary Stat,');
for jnd=1:length(heads.varnames2)
    fprintf(fid,[heads.varnames2{jnd} ',']);
end
fprintf(fid,'NumFailed,dev0-dev,df,p');
fprintf(fid,'\n');
for znd=1:cnt
    for ind=1:3
        if ind==1
            fprintf(fid,[heads.retro{ix.Comorb(znd)} ',']);
        else
            fprintf(fid,',');
        end
        fprintf(fid,heads.vars{ind});
        for jnd=1:length(heads.varnames2)
            fprintf(fid,[',' num2str(summary.bs2(znd,jnd,ind))]);
        end
        if ind==1
            fprintf(fid,[',,' num2str(summary.devs2(znd,2)-summary.devs2(znd,1)) ',']);
            fprintf(fid,[num2str(summary.bs2(znd,jnd,4)) ',' num2str(1-chi2cdf(summary.devs2(znd,2)-summary.devs2(znd,1),summary.bs2(znd,jnd,4)))]);
        end
        fprintf(fid,'\n');
    end
end
for znd=1:cnt2
    for ind=1:3
        if ind==1
            fprintf(fid,[heads.retro{ix.Counts(znd)} ',']);
        else
            fprintf(fid,',');
        end
        fprintf(fid,heads.vars{ind});
        for jnd=1:length(heads.varnames2)
            fprintf(fid,[',' num2str(summary.cnt.bs2(znd,jnd,ind))]);
        end
        if ind==1
            fprintf(fid,[',,' num2str(summary.cnt.devs2(znd,2)-summary.cnt.devs2(znd,1)) ',']);
            fprintf(fid,[num2str(summary.cnt.bs2(znd,jnd,4)) ',' num2str(1-chi2cdf(summary.cnt.devs2(znd,2)-summary.cnt.devs2(znd,1),summary.cnt.bs2(znd,jnd,4)))]);
        end
        fprintf(fid,'\n');
    end
end
fclose(fid);

%% All Pairwise Differences Between Classes
fprintf('Need to fix pairwise differences for Failed reason\n');
summary.pairwise=zeros(n.class+1,n.class+1,size(summary.bs,1),3);
for znd=1:size(summary.bs,1)
    for cnd=1:n.class+1
        for vnd=cnd+1:n.class+1
            if cnd==1
                summary.pairwise(cnd,vnd,znd,1)=-summary.bs(znd,vnd,1); % ES was coded as an intercept
            else
                summary.pairwise(cnd,vnd,znd,1)=summary.bs(znd,cnd,1)-summary.bs(znd,vnd,1); % mean dif
            end
            summary.pairwise(cnd,vnd,znd,2)=sqrt(summary.bs(znd,cnd,2)^2+summary.bs(znd,vnd,2)^2); % SE
            summary.pairwise(cnd,vnd,znd,3)=2*normcdf(-abs(summary.pairwise(cnd,vnd,znd,1)),0,summary.pairwise(cnd,vnd,znd,2));
        end
    end
end
summary.cnt.pairwise=zeros(n.class+1,n.class+1,size(summary.cnt.bs,1),3);
for znd=1:size(summary.cnt.bs,1)
    if znd==1 % # Comorbid shouldn't be regressed against itself
        summary.cnt.bs(znd,1:end-1,1:3)=summary.cnt.bs2(znd,:,1:3);
    end
    for cnd=1:n.class+1
        for vnd=cnd+1:n.class+1
            if cnd==1
                summary.cnt.pairwise(cnd,vnd,znd,1)=-summary.cnt.bs(znd,vnd,1); % mean dif
            else
                summary.cnt.pairwise(cnd,vnd,znd,1)=summary.cnt.bs(znd,cnd,1)-summary.cnt.bs(znd,vnd,1); % mean dif
            end
            summary.cnt.pairwise(cnd,vnd,znd,2)=sqrt(summary.cnt.bs(znd,cnd,2)^2+summary.cnt.bs(znd,vnd,2)^2); % SE
            summary.cnt.pairwise(cnd,vnd,znd,3)=2*normcdf(-abs(summary.cnt.pairwise(cnd,vnd,znd,1)),0,summary.cnt.pairwise(cnd,vnd,znd,2));
        end
    end
end
ix.cnt.sigpair=find(squeeze(summary.cnt.pairwise(1,3,:,3)<0.05));
ix.sigpair=find(squeeze(summary.pairwise(1,3,:,3)<0.05));
% ix.sigpair=intersect(ix.sigpair,ix.prev);

% data.pairwise =[dirs.analysis 'DescripPairwise.csv'];
fid=fopen(dirs.pairwise,'w');
fprintf(fid,'Variable/Class,P-value of difference,,,,,Z-difference\n');
for znd=1:size(summary.bs,1)
    fprintf(fid,[heads.retro{ix.Comorb(znd)}]);
    for cnd=2:n.class+1
        fprintf(fid,[',' heads.varnames{cnd}]);
    end
    for cnd=2:n.class+1
        fprintf(fid,[',' heads.varnames{cnd}]);
    end
    fprintf(fid,'\n');
    for cnd=1:n.class
        fprintf(fid,[heads.varnames{cnd}]);
        for vnd=2:n.class+1
            fprintf(fid,[',' num2str(summary.pairwise(cnd,vnd,znd,3))]);
        end
        for vnd=2:n.class+1
            fprintf(fid,[',' num2str(summary.pairwise(cnd,vnd,znd,1))]);
        end
        fprintf(fid,'\n');
    end
end
for znd=1:size(summary.cnt.bs,1)
    fprintf(fid,[heads.retro{ix.Counts(znd)}]);
    for cnd=2:n.class+1
        fprintf(fid,[',' heads.varnames{cnd}]);
    end
    for cnd=2:n.class+1
        fprintf(fid,[',' heads.varnames{cnd}]);
    end
    fprintf(fid,'\n');
    for cnd=1:n.class
        fprintf(fid,[heads.varnames{cnd}]);
        for vnd=2:n.class+1
            fprintf(fid,[',' num2str(summary.cnt.pairwise(cnd,vnd,znd,3))]);
        end
        for vnd=2:n.class+1
            fprintf(fid,[',' num2str(summary.cnt.pairwise(cnd,vnd,znd,1))]);
        end
        fprintf(fid,'\n');
    end
end
fclose(fid);

%% Descriptive Abstract Figure: Order & Significance of classes
% For assistance with ordering the classes and indicting the sigificant
% pairs
fid=fopen(dirs.DesOrd,'w');
fprintf(fid,'Variable,1,2,3,4,5,6,Sigs\n');
for znd=1:size(summary.pred,1)
    fprintf(fid,[heads.retro{znd} ',']);
    [tmp,iz]=sort(summary.pred(znd,:,1));
    for jnd=1:size(summary.pred,2)
        fprintf(fid,[num2str(iz(jnd)) ',']);
    end
    for jnd=1:size(summary.pred,2)
        if isempty(intersect(znd,ix.Counts))
            ip=find(ix.Comorb==znd); % find in the Comorb index
            tmp=[summary.pairwise(1:iz(jnd),iz(jnd),ip,3)',summary.pairwise(iz(jnd),(iz(jnd)+1):end,ip,3)];
        else
            ip=find(ix.Counts==znd); % find in the Counts Index
            tmp=[summary.cnt.pairwise(1:iz(jnd),iz(jnd),ip,3)',summary.cnt.pairwise(iz(jnd),(iz(jnd)+1):end,ip,3)];
        end
        is1=find(tmp<0.05);
        is2=setdiff(is1,iz(jnd));
        if ~isempty(is2)
            fprintf(fid,[num2str(iz(jnd)) '<']);
            for ind=1:length(is2)
                fprintf(fid,num2str(is2(ind)));
            end
            fprintf(fid,':');
        end
    end
    fprintf(fid,'\n');
end
fclose(fid);

%% Retrospective vs Prospective Prevalence Differences
data.prosp.prevalence=sum(data.testp);
% First do it agnostic of diagnosis
data.prevdif=zeros(length(data.prevalence),1);
% ix.Comorb     =[2:21, 23,24];
for ind=ix.Comorb
    fishermx=[data.prevalence(ind),data.prosp.prevalence(ind);
        n.retro-data.prevalence(ind),n.prosp.sub-data.prosp.prevalence(ind)];
    [h,data.prevdif(ind),stats]=fishertest(fishermx,'tail','both');
end
% ix.Counts     =[1,22,25:size(data.retro,2)];
for ind=ix.Counts
    [h,data.prevdif(ind)]=ttest2(data.retro(:,ind),data.testp(:,ind));
end

fid=fopen(dirs.retvpro,'w');
fprintf(fid,'Variable,Retro,Prosp,p,included\n');
for ind=1:size(data.retro,2)
    fprintf(fid,[heads.retro{ind} ',']);
    if isempty(intersect(ind,ix.Comorb)) % Continuous!
        fprintf(fid,[num2str(mean(data.retro(:,ind))) 'pm' num2str(1.96*std(data.retro(:,ind))/sqrt(n.retro)) ',']);
        fprintf(fid,[num2str(mean(data.testp(:,ind))) 'pm' num2str(1.96*std(data.testp(:,ind))/sqrt(n.prosp.sub)) ',']);
    else % Binary
        fprintf(fid,[num2str(data.prevalence(ind)/n.retro) ',' num2str(data.prosp.prevalence(ind)/n.prosp.sub) ',']);
    end
    fprintf(fid,[num2str(data.prevdif(ind)) ',']);
    if isempty(intersect(ind,ix.prev))
        fprintf(fid,[num2str(0) '\n']);
    else
        fprintf(fid,[num2str(1) '\n']);
    end
end
fclose(fid);

% By Diagnostic Class- With stats between PNES and ES
summary.retvpro.data=zeros(size(data.retro,2),length(ix.retvpro.classid),3,2);
% Index 1: Feature
% Index 2: Class
% Index 3: Dataset
% Index 4: Mean/SE
summary.retvpro.datadif=zeros(size(data.retro,2),length(ix.retvpro.classid));
summary.retvpro.p   =zeros(size(data.retro,2),3);
ix.all.classord=zeros(length(ix.all.classid),1);
tmps.classcnt=zeros(length(ix.all.classord),2);
for cnd=1:length(ix.all.classid)
    tmps.classcnt(cnd,1)=length(ix.retvpro.classid{cnd,1})+length(ix.retvpro.classid{cnd,2});
    tmps.classcnt(cnd,2)=length(ix.all.classid{cnd});
end
for cnd=1:length(ix.all.classid)
    ix.all.classord(cnd)=find(tmps.classcnt(:,2)==tmps.classcnt(cnd,1));
end
for ind=1:size(data.retro,2)
    for cnd=1:length(ix.retvpro.classid)
        for rnd=1:3 % retrospective, prospective
            if rnd==1
                summary.retvpro.data(ind,cnd,rnd,1)=mean(data.retro(ix.retvpro.classid{cnd,rnd},ind));
                summary.retvpro.data(ind,cnd,rnd,2)=std(data.retro(ix.retvpro.classid{cnd,rnd},ind))/sqrt(length(ix.retvpro.classid{cnd,rnd}));
            elseif rnd==2
                summary.retvpro.data(ind,cnd,rnd,1)=mean(data.testp(ix.retvpro.classid{cnd,rnd},ind));
                summary.retvpro.data(ind,cnd,rnd,2)=std(data.testp(ix.retvpro.classid{cnd,rnd},ind))/sqrt(length(ix.retvpro.classid{cnd,rnd}));
            else
                summary.retvpro.data(ind,cnd,rnd,1)=mean(data.all.compiled(ix.all.classid{ix.all.classord(cnd)},ind));
                summary.retvpro.data(ind,cnd,rnd,2)=std(data.all.compiled(ix.all.classid{ix.all.classord(cnd)},ind))/sqrt(length(ix.all.classid{ix.all.classord(cnd)}));
            end
        end
        [tmps.h,tmps.p]=ttest2(data.retro(ix.retvpro.classid{cnd,1},ind),data.testp(ix.retvpro.classid{cnd,2},ind),'tail','both','vartype','unequal');
        summary.retvpro.datadif(ind,cnd)=tmps.p;
    end
    for rnd=1:3
        if rnd==1
            [tmps.h,tmps.p]=ttest2(data.retro(ix.retvpro.classid{1,rnd},ind),data.retro(ix.retvpro.classid{3,rnd}),'tail','both','vartype','unequal');
        elseif rnd==2
            [tmps.h,tmps.p]=ttest2(data.testp(ix.retvpro.classid{1,rnd},ind),data.testp(ix.retvpro.classid{3,rnd}),'tail','both','vartype','unequal');
        else
            [tmps.h,tmps.p]=ttest2(data.all.compiled(ix.all.classid{ix.all.classord(1)},ind),data.all.compiled(ix.all.classid{ix.all.classord(3)}),'tail','both','vartype','unequal');
        end
        summary.retvpro.p(ind,rnd)=tmps.p;
    end
end
fprintf('Consider different retro vs pro distribution assumptions for PNES vs ES\n');

fid=fopen(dirs.retvproPNESvsES,'w');
fprintf(fid,',,');
for cnd=ix.classord
    fprintf(fid,[heads.varnames{cnd} ',,']);
end
fprintf(fid,'All,,\n');
fprintf(fid,'Variable,Dataset,');
for cnd=ix.classord
    fprintf(fid,['Mean,SE,']);
end
fprintf(fid,'Mean,SE,p-PNESvsES\n');
for ind=1:size(data.retro,2)
    fprintf(fid,[heads.retro{ind} ',']);
    for rnd=1:3 % retrospective, prospective
        if rnd==1
            fprintf(fid,'Retro,');
        elseif rnd==2
            fprintf(fid,',Prosp,');
        else
            fprintf(fid,',All,');
        end
        for cnd=[1 7 2 5 4 3 6]
            fprintf(fid,[num2str(summary.retvpro.data(ind,cnd,rnd,1)) ',' num2str(summary.retvpro.data(ind,cnd,rnd,2)) ',']);
        end
        fprintf(fid,[num2str(summary.retvpro.p(ind,rnd)) '\n']);
    end
    fprintf(fid,',p-RvP,');
    for cnd=[1 7 2 5 4 3 6]
        fprintf(fid,[num2str(summary.retvpro.datadif(ind,cnd)) ',,']);
    end
    fprintf(fid,',\n');
end
fclose(fid);

%% Descriptive Figures
%     Limit to Varibales with Sig difference
%     Label & Order the Classes
%     Errorbars
%     Done: Limit to ix.prev variables
ix.classord=[1 6 2 5 4 3];
figure;
ix.display.Comorb=intersect(ix.prev,ix.Comorb);
barDF=barh(summary.pred(ix.display.Comorb(end:-1:1),ix.classord,1),'BarWidth',1);
set(gca,'fontsize',16);
set(gca,'ytick',1:length(ix.display.Comorb),'yticklabel',{heads.retro{ix.display.Comorb(end:-1:1)}});
hold on
displ=[0.34 0.20 0.07 -0.07 -0.20 -0.34];
for ind=1:size(summary.pred,2)
    eb1=errbar(summary.pred(ix.display.Comorb(end:-1:1),ix.classord(ind),1),(1:length(ix.display.Comorb))-displ(ind),abs(summary.pred(ix.display.Comorb(end:-1:1),ix.classord(ind),1)-summary.pred(ix.display.Comorb(end:-1:1),ix.classord(ind),2)),abs(summary.pred(ix.display.Comorb(end:-1:1),ix.classord(ind),1)-summary.pred(ix.display.Comorb(end:-1:1),ix.classord(ind),3)),'horiz','LineWidth',2,'Color',[0 0 0]);
end
hold off
set(gca,'xlim',[0 0.28],'xtick',0:0.1:0.4,'xticklabel',{'0%','10%','20%','30%','40%'});
xlabel('Prevalence controlling for Age, Sex, Num Comorbidities');
set(barDF(1),... %'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName',heads.varnames{ix.classord(1)});
set(barDF(2),... %'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName',heads.varnames{ix.classord(2)});
set(barDF(3),... 'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName',heads.varnames{ix.classord(3)});
set(barDF(4),... %'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName',heads.varnames{ix.classord(4)});
set(barDF(5),... %'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName',heads.varnames{ix.classord(5)});
set(barDF(6),... %'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName',heads.varnames{ix.classord(6)});
legend1 = legend(gca,'show');

figure;
barDF=barh(summary.pred(ix.Counts(end:-1:1),ix.classord,1),'BarWidth',1);
set(gca,'fontsize',16);
set(gca,'ytick',1:length(ix.Counts),'yticklabel',{heads.retro{ix.Counts(end:-1:1)}});
hold on
displ=[0.34 0.20 0.07 -0.07 -0.20 -0.34];
% displ=[0.325 0.205 0.07 -0.07 -0.205 -0.325];
for ind=1:size(summary.pred,2)
    eb1=errbar(summary.pred(ix.Counts(end:-1:1),ix.classord(ind),1),(1:length(ix.Counts))-displ(ind),abs(summary.pred(ix.Counts(end:-1:1),ix.classord(ind),1)-summary.pred(ix.Counts(end:-1:1),ix.classord(ind),2)),abs(summary.pred(ix.Counts(end:-1:1),ix.classord(ind),1)-summary.pred(ix.Counts(end:-1:1),ix.classord(ind),3)),'horiz','LineWidth',2,'Color',[0 0 0]);
end
hold off
set(gca,'xlim',[0 3.5]);
set(barDF(1),... %'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName',heads.varnames{ix.classord(1)});
set(barDF(2),... %'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName',heads.varnames{ix.classord(2)});
set(barDF(3),... 'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName',heads.varnames{ix.classord(3)});
set(barDF(4),... %'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName',heads.varnames{ix.classord(4)});
set(barDF(5),... %'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName',heads.varnames{ix.classord(5)});
set(barDF(6),... %'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName',heads.varnames{ix.classord(6)});
legend1 = legend(gca,'show');

figure;
ix.cnt.usesig=[8,7,4:-1:1];
barDF=barh(summary.pred(ix.Counts(ix.cnt.sigpair(ix.cnt.usesig)),:,1),'BarWidth',1);
set(gca,'fontsize',16);
xlabel('Average Number, significants');
set(gca,'ytick',1:length(ix.cnt.usesig),'yticklabel',{heads.retro{ix.Counts(ix.cnt.sigpair(ix.cnt.usesig))}});
hold on
displ=[0.34 0.20 0.07 -0.07 -0.20 -0.34];
% displ=[0.325 0.205 0.07 -0.07 -0.205 -0.325];
for ind=1:size(summary.pred,2)
    eb1=errbar(summary.pred(ix.Counts(ix.cnt.sigpair(ix.cnt.usesig)),ix.classord(ind),1),(1:length(ix.cnt.usesig))-displ(ix.classord(ind)),abs(summary.pred(ix.Counts(ix.cnt.sigpair(ix.cnt.usesig)),ix.classord(ind),1)-summary.pred(ix.Counts(ix.cnt.sigpair(ix.cnt.usesig)),ix.classord(ind),2)),abs(summary.pred(ix.Counts(ix.cnt.sigpair(ix.cnt.usesig)),ix.classord(ind),1)-summary.pred(ix.Counts(ix.cnt.sigpair(ix.cnt.usesig)),ix.classord(ind),3)),'horiz','LineWidth',2,'Color',[0 0 0]);
end
hold off
set(gca,'xlim',[0,3]);
set(barDF(1),... %'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName',heads.varnames{ix.classord(1)});
set(barDF(2),... %'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName',heads.varnames{ix.classord(2)});
set(barDF(3),... 'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName',heads.varnames{ix.classord(3)});
set(barDF(4),... %'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName',heads.varnames{ix.classord(4)});
set(barDF(5),... %'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName',heads.varnames{ix.classord(5)});
set(barDF(6),... %'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName',heads.varnames{ix.classord(6)});
legend1 = legend(gca,'show');

figure
ix.sigComorb=[18,19,21,5,11,7,14];
% ix.sigComorb=intersect(ix.Comorb(ix.sigpair),ix.display.Comorb);
barDF=barh(summary.pred(ix.sigComorb(end:-1:1),ix.classord,1),'BarWidth',1);
set(gca,'fontsize',16);
set(gca,'ytick',1:length(ix.sigComorb),'yticklabel',{heads.retro{ix.sigComorb(end:-1:1)}});
xlabel('Frequency in each diagnostic group, significant factors');
set(gca,'xtick',0:0.05:0.2,'xticklabel',{'0%','5%','10%','15%','20%'});
set(gca,'xlim',[0 0.17]);
hold on
displ=[0.335 0.20 0.07 -0.07 -0.20 -0.335];
% displ=[0.325 0.205 0.07 -0.07 -0.205 -0.325];
for ind=1:size(summary.pred,2)
    eb1=errbar(summary.pred(ix.sigComorb(end:-1:1),ix.classord(ind),1),(1:length(ix.sigComorb))-displ(ind),abs(summary.pred(ix.sigComorb(end:-1:1),ix.classord(ind),1)-summary.pred(ix.sigComorb(end:-1:1),ix.classord(ind),2)),abs(summary.pred(ix.sigComorb(end:-1:1),ix.classord(ind),1)-summary.pred(ix.sigComorb(end:-1:1),ix.classord(ind),3)),'horiz','LineWidth',3,'Color',[0 0 0]);
end
hold off
set(barDF(1),... %'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName',heads.varnames{ix.classord(1)});
set(barDF(2),... %'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName',heads.varnames{ix.classord(2)});
set(barDF(3),... 'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName',heads.varnames{ix.classord(3)});
set(barDF(4),... %'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName',heads.varnames{ix.classord(4)});
set(barDF(5),... %'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName',heads.varnames{ix.classord(5)});
set(barDF(6),... %'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName',heads.varnames{ix.classord(6)});
legend1 = legend(gca,'show');

% Write all this out for a table
fid=fopen(dirs.datatable,'w');
fprintf('Data Table: Need to work on rounding\n');
fprintf(fid,'Need to Fix Rounding Issue,');
for cnd=ix.classord
    fprintf(fid,[heads.varnames{cnd} ',,']);
end
fprintf(fid,',\n');
fprintf(fid,'Variable,');
for cnd=ix.classord
    fprintf(fid,'Mean,95CI,');
end
fprintf(fid,'p-PNESvsES\n');
for vnd=1:size(summary.pred,1)
    fprintf(fid,[heads.retro{vnd} ',']);
    for cnd=ix.classord
        fprintf(fid,[num2str(summary.pred(vnd,cnd,1)) ',(' num2str(summary.pred(vnd,cnd,2)) '-' num2str(summary.pred(vnd,cnd,3)) '),']);
    end
    if intersect(vnd,ix.Comorb)
        fprintf(fid,num2str(summary.pairwise(1,3,find(ix.Comorb==vnd),3)));
    elseif intersect(vnd,ix.Counts)
        fprintf(fid,num2str(summary.cnt.pairwise(1,3,find(ix.Counts==vnd),3)));
    end
    fprintf(fid,'\n');
end
fclose(fid);

%% Non-metastatic Neoplasia list
ix.nmetneo=5;
ix.retro.nmetneo=find(data.retro(:,ix.nmetneo));
ix.prosp.nmetneo=find(data.testp(:,ix.nmetneo));
fid=fopen(dirs.nmetneo,'w');
fprintf(fid,'MRN,NonMetastaticNeoplasia\n');
fprintf(fid,'Retro\n');
for ind=1:length(ix.retro.nmetneo)
    fprintf(fid,[num2str(data.MRNdata(ix.retro.nmetneo(ind))) '\n']);
end
fprintf(fid,'Prosp\n');
for ind=1:length(ix.prosp.nmetneo)
    fprintf(fid,[num2str(data.prosp.MRN(ix.prosp.nmetneo(ind),1)) '\n']);
end
fclose(fid);

%% Random Discussion Factoids
ix.ASMfailed=31-5;
summary.ASMfailures=zeros(n.class,2);
for cnd=1:n.class
    summary.ASMfailures(cnd,1)=mean(data.all.compiled(ix.all.classid{cnd},ix.ASMfailed)>2);
    summary.ASMfailures(cnd,2)=length(ix.all.classid{cnd});
end

%% Check Yield of Interviews
fid=fopen(dirs.allpts,'r');
d=textscan(fid,'%s %f %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s','Delimiter',',','Headerlines',1);
fclose(fid);

ix.allptsMRN=2;
ix.allptsdate=1;
beforelast=zeros(length(d{1}),1);
for ind=1:length(d{1})
    beforelast(ind)=(datetonum(d{ix.allptsdate}{ind})<=data.lastdate);
end
data.allptsMRN=unique(d{ix.allptsMRN}(find(beforelast))); 
% excluding doubles, patient admitted after interviews were updated
n.allpts=sum(~isnan(data.allptsMRN));
data.allpts=zeros(n.allpts,2);
data.allpts(:,1)=data.allptsMRN(find(~isnan(unique(d{ix.allptsMRN}(find(beforelast))))));
for ind=1:n.allpts
    if intersect(data.allpts(ind,1),data.MRNDx)
        data.allpts(ind,2)=1;
    elseif intersect(data.allpts(ind,1),data.prosp.MRN)
        data.allpts(ind,2)=2;
    end
end

% Note: excluding retrospective re-admissions
out.yield=sum(data.allpts(:,2)==2)/(sum(~data.allpts(:,2))+sum(data.allpts(:,2)==2));